template: base.jinja.html
footnote: Generated with Anchovy!

# Photo Gallery

<div class="gallery">
    <a href="static/images/home-sweet-home-cdk.webp"><img src="static/images/home-sweet-home-cdk.thumb.png" alt="A Vintage Automobile"></a>
    <a href="static/images/nice-wheels-cdk.webp"><img src="static/images/nice-wheels-cdk.thumb.png" alt="A Old Wood-Sided House"></a>
    <a href="static/images/stormy-cdk.webp"><img src="static/images/stormy-cdk.thumb.png" alt="A Boardwalk and Damaged Pines During a Storm"></a>
    <a href="static/images/quayside-newcastle.webp"><img src="static/images/quayside-newcastle.thumb.png" alt="A Quay in Newcastle, England"></a>
</div>
